"""Testes do módulo device."""

from tecjustica_ocr.device import resolve_device


def test_resolve_cpu():
    assert resolve_device("cpu") == "cpu"


def test_resolve_gpu():
    assert resolve_device("gpu:0") == "gpu:0"


def test_resolve_auto():
    result = resolve_device("auto")
    assert result in ("gpu:0", "cpu")
